Tutorials
=========

.. toctree::
   :maxdepth: 1
   :caption: Tutorials

   categorical_data
   sklearn_interface.ipynb
   benchmark
   calibration/regression_calibration.ipynb
   calibration/classification_calibration.ipynb
   custom_objective.ipynb
   causal/uplift_marketing.ipynb
   causal/iv_causal_effect.ipynb
   causal/dml_wage_gap.ipynb
   causal/policy_learning.ipynb
   causal/risk_compliance.ipynb
   causal/heterogeneous_treatment_effects.ipynb
   causal/fairness_aware_modeling.ipynb
   causal/fair_classification.ipynb
   causal/customer_retention_uplift.ipynb
   drift_tutorial.ipynb
   objectives_tutorial.ipynb
